@@ -21,10 +21,8 @@
  */
 
 #include <QtGui/QApplication>
-#include <QtGui/QGraphicsScene>
 #include <QtGui/QGraphicsView>
-#include <QtCore/QState>
-#include <QStateMachine>
+#include <QtCore/QStateMachine>
 
 #include "applicationmanager.h"
 
@@ -35,31 +33,37 @@
 int main (int argc, char **argv)
 {
     QApplication app(argc, argv);
+    QApplication::setOrganizationName("Zagaia");
+    QApplication::setApplicationName("TweeGo");
 
     QGraphicsScene scene(0, 0, 800, 480);
     QGraphicsView view(&scene);
 
     QStateMachine machine;
-    QState *splashState = new QState();
     QState *loginState = new QState();
     QState *timelineState = new QState();
 
     ApplicationManager *appManager = new ApplicationManager(&scene);
 
-    splashState->addTransition(appManager,SIGNAL(splashFinished()),loginState);
     loginState->addTransition(appManager,SIGNAL(loginFinished()),timelineState);
     timelineState->addTransition(appManager,SIGNAL(timelineFinished()),loginState);
 
-    QObject::connect(splashState,SIGNAL(entered()),appManager,SLOT(splashScreen()));
     QObject::connect(loginState,SIGNAL(entered()),appManager,SLOT(loginScreen()));
     QObject::connect(timelineState,SIGNAL(entered()),appManager,SLOT(timelineScreen()));
 
     QObject::connect(&machine, SIGNAL(finished()), QApplication::instance(), SLOT(quit()));
 
-    machine.addState(splashState);
     machine.addState(loginState);
     machine.addState(timelineState);
-    machine.setInitialState(splashState);
+    machine.setInitialState(loginState);
+
+//    QNetworkProxy proxy;
+//    proxy.setType(QNetworkProxy::HttpProxy);
+//    proxy.setHostName("172.19.244.1");
+//    proxy.setPort(3128);
+//    proxy.setUser("indt.mikhail.gadelha");
+//    proxy.setPassword("indt.mikhail.gadelha");
+//    QNetworkProxy::setApplicationProxy(proxy);
 
     machine.start();
 
