@@ -44,6 +44,7 @@ const QString XmlParser::TAG_PROFILE_TIMESTAMP = "created_at";
 const QString XmlParser::TAG_UTC_OFFSET = "utc_offset";
 const QString XmlParser::TAG_STATUS_COUNT = "statuses_count";
 const QString XmlParser::TAG_SOURCE = "source";
+const QString XmlParser::TAG_RETWEET_COUNT = "retweet_count";
 
 const QString XmlParserDirectMsg::TAG_DIRECT_MESSAGE = "direct_message";
 const QString XmlParserDirectMsg::TAG_SENDER = "sender";
@@ -52,7 +53,7 @@ const QSet<QString> XmlParser::tags = QSet<QString>() << TAG_STATUS_ID << TAG_US
                                       << TAG_USER_IMAGE << TAG_USER_HOMEPAGE << TAG_USER_TIMESTAMP << TAG_INREPLYTO_STATUS_ID
                                       << TAG_INREPLYTO_SCREEN_NAME << TAG_USER_ID << TAG_LOCATION << TAG_DESCRIPTION
                                       << TAG_FOLLOWERS_COUNT << TAG_FRIENDS_COUNT << TAG_STATUS_COUNT << TAG_FAVORITED
-                                      << TAG_UTC_OFFSET << TAG_SOURCE;
+                                      << TAG_UTC_OFFSET << TAG_SOURCE << TAG_RETWEET_COUNT;
 
 const int XmlParser::timeShift = XmlParser::calculateTimeShift();
 
@@ -159,6 +160,8 @@ bool XmlParser::characters( const QString &ch )
                 if( !ch.trimmed().isEmpty() ) {
                     entry.source = ch;
                 }
+            } else if ( currentTag == TAG_RETWEET_COUNT && entry.retweet_count == 0) {
+                entry.retweet_count = ch.toInt();
             } else if ( currentTag == TAG_USER_TIMESTAMP && entry.timestamp.isNull() ) {
                 entry.timestamp = toDateTime( ch ); //utc
                 /* It's better to leave UTC timestamp alone; Additional member localTime is added to store local time when
